@@ -20,7 +20,7 @@ import pandas
 import numpy
 import math
 
-VERSION = "slendr_0.3.0.9000"
+VERSION = "slendr_0.6.0"
 
 
 def simulate(
@@ -31,7 +31,7 @@ def simulate(
   """Run a slendr simulation and return a tree sequence."""
 
   logging.info("Setting up populations")
-  
+
   # set up demographic history
   demography = msprime.Demography()
   for pop in populations.itertuples():
@@ -44,7 +44,7 @@ def simulate(
           initial_size = resize_events.tail(1).N.values[0]
       else:
           initial_size = pop.N
-  
+
       logging.info(f"Setting up population {pop.pop} with Ne {initial_size}")
       demography.add_population(
           name=pop.pop,
@@ -54,14 +54,14 @@ def simulate(
       # for non-ancestral populations, specify the correct split event and re-set
       # the effective population size (by default in msprime inherited from the
       # parent population)
-      if pop.parent != "ancestor":
+      if pop.parent != "__pop_is_ancestor":
           demography.add_population_split(
               time=length - pop.tsplit_gen,
               derived=[pop.pop],
               ancestral=pop.parent
           )
-  
-  if not isinstance(samples, pandas.DataFrame) or not len(samples):
+
+  if len(samples) == 0:
       logging.info("No sampling schedule given, generating one automatically")
       samples = pandas.DataFrame(
           [
@@ -70,16 +70,16 @@ def simulate(
           ],
           columns=["n", "pop", "time_gen", "x", "y", "time_orig", "x_orig", "y_orig"]
       )
-  
+
   logging.info("Loading the sampling schedule")
   sample_set = [
       msprime.SampleSet(
          row.n, population=row.pop, time=length - row.time_gen + 1, ploidy=2
       ) for row in samples.itertuples(index=False)
   ]
-  
+
   logging.info("Setting up population resize events")
-  
+
   # schedule population size changes
   for event in resizes.itertuples(index=False):
       if event.how == "step":
@@ -107,9 +107,9 @@ def simulate(
           )
       else:
           sys.exit(f"Unknown event type '{event.how}'")
-  
+
   logging.info("Setting up gene flow events")
-  
+
   # schedule gene flow events
   for event in geneflows.itertuples():
       tstart = length - event.tend_gen + 1
@@ -127,16 +127,16 @@ def simulate(
           source=event.to,
           dest=event._1,
       )
-  
+
   # make sure all slendr events are sorted by time of occurence
   # (otherwise msprime complains)
   demography.sort_events()
-  
+
   if debug:
       print(demography.debug())
-  
+
   logging.info("Running the simulation and generating a tree sequence")
-  
+
   ts = msprime.sim_ancestry(
       samples=sample_set,
       demography=demography,
@@ -144,11 +144,19 @@ def simulate(
       recombination_rate=recombination_rate,
       random_seed=seed
   )
-  
+
+  # symbolic names of individuals that have been recorded in the tree sequence
+  # (this vector is used in downstream analyses to keep track of which individuals
+  # were kept during the process of ts_simplify() etc.)
+  sample_names = []
+  for pop in samples["pop"].unique():
+      n = sum(samples[samples["pop"] == pop]["n"])
+      sample_names += [f"{pop}_{i}" for i in range(1, n + 1)]
+
   # compile a set of slendr metadata to be stored in the tree sequence
   slendr_metadata = {
       "slendr": {
-          "version": "slendr_0.3.0.9000",
+          "version": "slendr_0.6.0",
           "backend": "msprime",
           "description": description,
           "sampling": {
@@ -161,6 +169,7 @@ def simulate(
               "x_orig" : list(samples["x_orig"].astype(numpy.float32)),
               "y_orig" : list(samples["y_orig"].astype(numpy.float32))
           },
+          "sample_names": sample_names,
           "arguments": {
             "SEQUENCE_LENGTH"   : sequence_length,
             "RECOMB_RATE"       : recombination_rate,
@@ -169,15 +178,15 @@ def simulate(
           }
       }
   }
-  
+
   tables = ts.dump_tables()
   tables.metadata_schema = tskit.MetadataSchema({"codec": "json"})
   tables.metadata = slendr_metadata
-  
+
   ts_metadata = tables.tree_sequence()
-  
+
   logging.info("DONE")
-  
+
   return ts_metadata
 
 
@@ -202,22 +211,22 @@ if __name__ == "__main__":
                       help="Print detailed logging information?")
   parser.add_argument("--debug", action="store_true", default=False,
                       help="Print detailed debugging information?")
-  
+
   args = parser.parse_args()
-  
+
   if args.verbose:
       logging.basicConfig(level=logging.INFO)
-  
+
   model_dir = os.path.expanduser(args.model)
-  
+
   logging.info(f"Loading slendr model configuration files from {model_dir}")
-  
+
   if not args.output:
       args.output = pathlib.Path(model_dir, "output_msprime_ts.trees")
-  
+
   if not os.path.exists(model_dir):
       sys.exit(f"Model directory {model_dir} does not exist")
-  
+
   # paths to mandatory slendr configuration files
   populations_path = pathlib.Path(model_dir, "populations.tsv")
   resizes_path = pathlib.Path(model_dir, "resizes.tsv")
@@ -225,25 +234,25 @@ if __name__ == "__main__":
   length_path = pathlib.Path(model_dir, "length.txt")
   direction_path = pathlib.Path(model_dir, "direction.txt")
   description_path = pathlib.Path(model_dir, "description.txt")
-  
+
   # read model configuration files
   populations = pandas.read_table(populations_path)
   resizes = pandas.DataFrame()
   geneflows = pandas.DataFrame()
   samples = pandas.DataFrame()
-  
+
   if os.path.exists(resizes_path):
       resizes = pandas.read_table(resizes_path)
   if os.path.exists(geneflows_path):
       geneflows = pandas.read_table(geneflows_path)
-  
+
   # read the total simulation length
   length = int(float(open(length_path, "r").readline().rstrip()))
-  
+
   # read the direction of the model ("forward" or "backward")
   direction = open(direction_path, "r").readline().rstrip()
   logging.info(f"Loaded model is specified in the {direction} direction")
-  
+
   # read the description of the model
   description = open(description_path, "r").readline().rstrip()
   logging.info(f"Model description: {description}")
@@ -255,7 +264,7 @@ if __name__ == "__main__":
   ts = simulate(args.sequence_length, args.recombination_rate, args.seed,
                 populations, resizes, geneflows, length, direction, description,
                 samples, args.debug)
-  
+
   output_path = os.path.expanduser(args.output)
 
   logging.info(f"Saving tree sequence output to {output_path}")
